@@ -1,7 +1,7 @@
 import collections
 import io
-import errno
 import os
+import errno
 import pathlib
 import sys
 import shutil
@@ -9,7 +9,10 @@ import tempfile
 import unittest
 from contextlib import contextmanager
 
-from test import support
+try:
+    from test import support
+except ImportError:
+    from test import test_support as support
 TESTFN = support.TESTFN
 
 
@@ -220,9 +223,11 @@ class _BasePurePathTest(unittest.TestCase):
             self.assertEqual(P(pathstr).as_posix(), pathstr)
         # Other tests for as_posix() are in test_equivalences()
 
+    @unittest.skipIf(sys.version_info < (3, 2),
+                     'os.fsencode has been introduced in version 3.2')
     def test_as_bytes_common(self):
-        P = self.cls
         sep = os.fsencode(self.sep)
+        P = self.cls
         self.assertEqual(P('a/b').as_bytes(), b'a' + sep + b'b')
         self.assertEqual(bytes(P('a/b')), b'a' + sep + b'b')
 
@@ -321,13 +326,16 @@ class _BasePurePathTest(unittest.TestCase):
         self.assertEqual(p.parent(), P('a/b'))
         self.assertEqual(p.parent(2), P('a'))
         self.assertEqual(p.parent(3), P())
-        self.assertEqual(p.parent(4), P())
+        self.assertRaises(ValueError, p.parent, 4)
         # Anchored
         p = P('/a/b/c')
         self.assertEqual(p.parent(), P('/a/b'))
         self.assertEqual(p.parent(2), P('/a'))
         self.assertEqual(p.parent(3), P('/'))
-        self.assertEqual(p.parent(4), P('/'))
+        self.assertRaises(ValueError, p.parent, 4)
+        # Invalid level values
+        self.assertRaises(ValueError, p.parent, 0)
+        self.assertRaises(ValueError, p.parent, -1)
 
     def test_parents_common(self):
         # Relative
@@ -524,16 +532,16 @@ class PureNTPathTest(_BasePurePathTest):
         self.assertEqual(p.parent(), P('z:a/b'))
         self.assertEqual(p.parent(2), P('z:a'))
         self.assertEqual(p.parent(3), P('z:'))
-        self.assertEqual(p.parent(4), P('z:'))
+        self.assertRaises(ValueError, p.parent, 4)
         p = P('z:/a/b/c')
         self.assertEqual(p.parent(), P('z:/a/b'))
         self.assertEqual(p.parent(2), P('z:/a'))
         self.assertEqual(p.parent(3), P('z:/'))
-        self.assertEqual(p.parent(4), P('z:/'))
+        self.assertRaises(ValueError, p.parent, 4)
         p = P('//a/b/c/d')
         self.assertEqual(p.parent(), P('//a/b/c'))
         self.assertEqual(p.parent(2), P('//a/b'))
-        self.assertEqual(p.parent(3), P('//a/b'))
+        self.assertRaises(ValueError, p.parent, 3)
 
     def test_parents(self):
         # Anchored
@@ -688,6 +696,8 @@ class PurePathTest(_BasePurePathTest):
         q = pathlib.PureNTPath('a')
         self.assertNotEqual(p, q)
 
+    @unittest.skipIf(sys.version_info < (3, 0),
+                     'Most types are orderable in Python 2')
     def test_different_flavours_unordered(self):
         p = pathlib.PurePosixPath('a')
         q = pathlib.PureNTPath('a')
@@ -801,8 +811,9 @@ class _BasePathTest(unittest.TestCase):
         self.assertIs(True, p.exists())
         self.assertIs(True, p['dirA'].exists())
         self.assertIs(True, p['fileA'].exists())
-        self.assertIs(True, p['linkA'].exists())
-        self.assertIs(True, p['linkB'].exists())
+        if not symlink_skip_reason:
+            self.assertIs(True, p['linkA'].exists())
+            self.assertIs(True, p['linkB'].exists())
         self.assertIs(False, p['foo'].exists())
         self.assertIs(False, P('/xyzzy').exists())
 
@@ -873,11 +884,12 @@ class _BasePathTest(unittest.TestCase):
         p = P(BASE, 'dirB', 'linkD', 'fileB')
         self._check_resolve_relative(p, P(BASE, 'dirB', 'fileB'))
         # Now create absolute symlinks
-        with tempfile.TemporaryDirectory(suffix='-dirD') as d:
-            os.symlink(os.path.join(d), join('dirA', 'linkX'))
-            os.symlink(join('dirB'), os.path.join(d, 'linkY'))
-            p = P(BASE, 'dirA', 'linkX', 'linkY', 'fileB')
-            self._check_resolve_absolute(p, P(BASE, 'dirB', 'fileB'))
+        d = tempfile.mkdtemp(suffix='-dirD')
+        self.addCleanup(support.rmtree, d)
+        os.symlink(os.path.join(d), join('dirA', 'linkX'))
+        os.symlink(join('dirB'), os.path.join(d, 'linkY'))
+        p = P(BASE, 'dirA', 'linkX', 'linkY', 'fileB')
+        self._check_resolve_absolute(p, P(BASE, 'dirB', 'fileB'))
 
     def test_with(self):
         p = self.cls(BASE)
